@@ -14,9 +14,9 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.algo.conformance import alignments, tokenreplay, log_skeleton, footprints, temporal_profile
+from pm4py.algo.conformance import alignments, tokenreplay, log_skeleton, footprints
 
 import sys
 # this package is available only for Python >= 3.6
 if sys.version_info >= (3, 6):
-    from pm4py.algo.conformance import tree_alignments
+    pass
