@@ -20,7 +20,19 @@ from pm4py.util import constants
 from pm4py.algo.discovery.dfg.adapters.pandas import df_statistics
 from pm4py.util import exec_utils, pandas_utils
 from pm4py.algo.discovery.causal import algorithm as causal_discovery
-from pm4py.algo.discovery.footprints.outputs import Outputs
+from enum import Enum
+
+class Outputs(Enum):
+    DFG = "dfg"
+    SEQUENCE = "sequence"
+    PARALLEL = "parallel"
+    START_ACTIVITIES = "start_activities"
+    END_ACTIVITIES = "end_activities"
+    ACTIVITIES = "activities"
+    SKIPPABLE = "skippable"
+    ACTIVITIES_ALWAYS_HAPPENING = "activities_always_happening"
+    MIN_TRACE_LENGTH = "min_trace_length"
+    TRACE = "trace"
 
 
 class Parameters(Enum):
