@@ -14,11 +14,26 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.objects.process_tree.pt_operator import Operator
-from pm4py.algo.discovery.footprints.outputs import Outputs
-from pm4py.objects.process_tree import bottomup as bottomup_disc
+from pm4py.objects.process_tree.obj import Operator
+from pm4py.objects.process_tree.utils import bottomup as bottomup_disc
 from copy import copy
 
+from enum import Enum
+
+
+class Outputs(Enum):
+    DFG = "dfg"
+    SEQUENCE = "sequence"
+    PARALLEL = "parallel"
+    START_ACTIVITIES = "start_activities"
+    END_ACTIVITIES = "end_activities"
+    ACTIVITIES = "activities"
+    SKIPPABLE = "skippable"
+    ACTIVITIES_ALWAYS_HAPPENING = "activities_always_happening"
+    MIN_TRACE_LENGTH = "min_trace_length"
+    TRACE = "trace"
+
+
 START_ACTIVITIES = Outputs.START_ACTIVITIES.value
 END_ACTIVITIES = Outputs.END_ACTIVITIES.value
 ACTIVITIES = Outputs.ACTIVITIES.value
@@ -342,7 +357,7 @@ def get_footprints(node, footprints_dictio):
         return get_footprints_leaf(node, footprints_dictio)
     elif node.operator == Operator.XOR:
         return get_footprints_xor(node, footprints_dictio)
-    elif node.operator == Operator.PARALLEL:
+    elif node.operator == Operator.PARALLEL or node.operator == Operator.OR:
         return get_footprints_parallel(node, footprints_dictio)
     elif node.operator == Operator.SEQUENCE:
         return get_footprints_sequence(node, footprints_dictio)
