@@ -82,27 +82,27 @@ def apply_numeric(log, int1, int2, parameters=None):
         stream = EventStream(
             list(filter(lambda x: stream_filter_key1 in x and x[stream_filter_key1] == stream_filter_value1, stream)),
             attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
-            omni_present=log.omni_present)
+            omni_present=log.omni_present, properties=log.properties)
     if stream_filter_key2 is not None:
         stream = EventStream(
             list(filter(lambda x: stream_filter_key2 in x and x[stream_filter_key2] == stream_filter_value2, stream)),
             attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
-            omni_present=log.omni_present)
+            omni_present=log.omni_present, properties=log.properties)
 
     if positive:
         stream = EventStream(list(filter(lambda x: attribute_key in x and int1 <= x[attribute_key] <= int2, stream)),
                              attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
-                             omni_present=log.omni_present)
+                             omni_present=log.omni_present, properties=log.properties)
     else:
         stream = EventStream(
             list(filter(lambda x: attribute_key in x and (x[attribute_key] < int1 or x[attribute_key] > int2), stream)),
             attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
-            omni_present=log.omni_present)
+            omni_present=log.omni_present, properties=log.properties)
 
     all_cases_ids = set(x["case:" + case_key] for x in stream)
 
     filtered_log = EventLog(list(), attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
-                            omni_present=log.omni_present)
+                            omni_present=log.omni_present, properties=log.properties)
 
     for case in log:
         if case.attributes[case_key] in all_cases_ids:
@@ -142,12 +142,12 @@ def apply_numeric_events(log, int1, int2, parameters=None):
     if exec_utils.get_param_value(Parameters.POSITIVE, parameters, True):
         stream = EventStream(list(filter(lambda x: attribute_key in x and int1 <= x[attribute_key] <= int2, stream)),
                              attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
-                             omni_present=log.omni_present)
+                             omni_present=log.omni_present, properties=log.properties)
     else:
         stream = EventStream(
             list(filter(lambda x: attribute_key in x and (x[attribute_key] < int1 or x[attribute_key] > int2), stream)),
             attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
-            omni_present=log.omni_present)
+            omni_present=log.omni_present, properties=log.properties)
     filtered_log = log_converter.apply(stream)
 
     return filtered_log
@@ -183,11 +183,11 @@ def apply_events(log, values, parameters=None):
     if positive:
         stream = EventStream(list(filter(lambda x: x[attribute_key] in values, stream)), attributes=log.attributes,
                              extensions=log.extensions, classifiers=log.classifiers,
-                             omni_present=log.omni_present)
+                             omni_present=log.omni_present, properties=log.properties)
     else:
         stream = EventStream(list(filter(lambda x: x[attribute_key] not in values, stream)), attributes=log.attributes,
                              extensions=log.extensions, classifiers=log.classifiers,
-                             omni_present=log.omni_present)
+                             omni_present=log.omni_present, properties=log.properties)
 
     filtered_log = log_converter.apply(stream)
 
@@ -222,7 +222,7 @@ def apply(log, values, parameters=None):
     positive = exec_utils.get_param_value(Parameters.POSITIVE, parameters, True)
 
     filtered_log = EventLog(list(), attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
-                            omni_present=log.omni_present)
+                            omni_present=log.omni_present, properties=log.properties)
     for trace in log:
         new_trace = Trace()
 
@@ -271,7 +271,7 @@ def apply_trace_attribute(log, values, parameters=None):
     positive = exec_utils.get_param_value(Parameters.POSITIVE, parameters, True)
 
     filtered_log = EventLog(list(), attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
-                            omni_present=log.omni_present)
+                            omni_present=log.omni_present, properties=log.properties)
     for trace in log:
         if positive:
             if attribute_key in trace.attributes and trace.attributes[attribute_key] in values:
@@ -341,7 +341,7 @@ def filter_log_by_attributes_threshold(log, attributes, variants, vc, threshold,
         Filtered log
     """
     filtered_log = EventLog(list(), attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
-                            omni_present=log.omni_present)
+                            omni_present=log.omni_present, properties=log.properties)
     fva = [x[attribute_key] for x in variants[vc[0][0]][0] if attribute_key in x]
     for trace in log:
         new_trace = Trace()
