@@ -44,8 +44,8 @@ from pm4py.evaluation.soundness.woflan.place_invariants.s_component import compu
 from pm4py.evaluation.soundness.woflan.place_invariants.utility import \
     compute_uncovered_places as compute_uncovered_place_in_invariants
 from pm4py.evaluation.soundness.woflan.place_invariants.utility import transform_basis
-from pm4py.objects.petri import utils
-from pm4py.objects.petri.petrinet import PetriNet
+from pm4py.objects.petri_net.utils import petri_utils
+from pm4py.objects.petri_net.obj import PetriNet
 from pm4py.util import exec_utils
 
 
@@ -267,8 +267,8 @@ def short_circuit_petri_net(net, print_diagnostics=False):
         t_1 = PetriNet.Transition("short_circuited_transition", "short_circuited_transition")
         s_c_net.transitions.add(t_1)
         # add arcs in short-circuited net
-        utils.add_arc_from_to(sink, t_1, s_c_net)
-        utils.add_arc_from_to(t_1, source, s_c_net)
+        petri_utils.add_arc_from_to(sink, t_1, s_c_net)
+        petri_utils.add_arc_from_to(t_1, source, s_c_net)
         return s_c_net
     else:
         if sink is None:
