@@ -16,7 +16,7 @@
 '''
 from pm4py.objects.log.util import insert_classifier, log, sampling, \
     sorting, index_attribute, get_class_representation, get_log_representation, get_prefixes, \
-    get_log_encoded, interval_lifecycle, log_regex, basic_filter, func
+    get_log_encoded, interval_lifecycle, log_regex, basic_filter
 import pkgutil
 
 if pkgutil.find_loader("pandas"):
