@@ -1,3 +1,19 @@
+'''
+    This file is part of PM4Py (More Info: https://pm4py.fit.fraunhofer.de).
+
+    PM4Py is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    PM4Py is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
+'''
 from pm4py.util.xes_constants import DEFAULT_TIMESTAMP_KEY
 import statistics
 from pm4py.util.business_hours import BusinessHours
@@ -54,7 +70,7 @@ def get_case_arrival_avg(log, parameters=None):
             case_diff_start_time.append((case_start_time[i+1]-case_start_time[i]).total_seconds())
 
     if case_diff_start_time:
-        return statistics.median(case_diff_start_time)
+        return statistics.mean(case_diff_start_time)
 
     return 0.0
 
@@ -97,6 +113,6 @@ def get_case_dispersion_avg(log, parameters=None):
             case_diff_end_time.append((case_end_time[i+1]-case_end_time[i]).total_seconds())
 
     if case_diff_end_time:
-        return statistics.median(case_diff_end_time)
+        return statistics.mean(case_diff_end_time)
 
     return 0.0
