@@ -15,3 +15,6 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from pm4py.visualization.petrinet import visualizer, common, util, variants
+import warnings
+
+warnings.warn("please use the pm4py.visualization.petri_net package instead")
